## Short Info
Replace numerals with corresponding numbers in the given text.
Available on [PyPI](https://pypi.org/project/numberize/).
Consider checking out [Wiki](https://github.com/DanATW/numberize/wiki) for more info.
## Supported languages
* Ukrainian
* Russian
## Requirements
* python 3.6+
## How to install it?
```pip install numberize```
## How to use it?
```
import numberize
numberizer = numberize.Numberizer(lang='ru')    #or 'uk'
new_text = numberizer.replace_numerals(old_text)
   ```
